@@ -6,13 +6,13 @@ use base FCGI::ProcManager;
 # Public License, Version 3.  Please read the important licensing and
 # disclaimer information included below.
 
-# $Id: Dynamic.pm,v 0.6 2012/06/29 11:00:00 Andrey Velikoredchanin $
+# $Id: Dynamic.pm,v 0.7 2017/03/09 12:17:00 Andrey Velikoredchanin $
 
 use strict;
 
 use vars qw($VERSION);
 BEGIN {
-	$VERSION = '0.6';
+	$VERSION = '0.7';
 }
 
 use POSIX;
@@ -132,7 +132,7 @@ sub pm_manage
 	$self->{_last_delta_time} = time();
 
 	# Создает очередь сообщений
-	if (!($self->{ipcqueue} = msgget(IPC_PRIVATE, IPC_CREAT | 0666))) {
+	if (!defined($self->{ipcqueue} = msgget(IPC_PRIVATE, IPC_CREAT | 0666))) {
 		die "Cannot create shared message pipe!";
 	};
 
@@ -202,6 +202,13 @@ sub pm_wait
 				$pid = -10;
 				$self->{_last_delta_time} = time();
 			};
+		elsif (keys(%{$self->{PIDS}}) < $self->{min_nproc}) 
+		{
+			# Если количество процессов меньше минимального - добавляем
+			$self->pm_notify("increase workers to minimal ".$self->{min_nproc});
+			$self->SUPER::n_processes($self->{min_nproc});
+			$self->{_last_delta_time} = time();
+			$pid = -10;
 		}
 		elsif (($self->{USED_PROCS} < $self->{min_nproc}) && ((time() - $self->{_last_delta_time}) >= $self->{delta_time}))
 		{
@@ -243,13 +250,6 @@ sub pm_wait
 			$self->{_last_delta_time} = time();
 			$pid = -10;
 		}
-		elsif (keys(%{$self->{PIDS}}) < $self->{min_nproc}) 
-		{
-			# Если количество процессов меньше минимального - добавляем
-			$self->pm_notify("increase workers to minimal ".$self->{min_nproc});
-			$self->SUPER::n_processes($self->{min_nproc});
-			$self->{_last_delta_time} = time();
-			$pid = -10;
 		}
 		elsif ($self->{USED_PROCS} >= ($self->{n_processes} - $self->{delta_nproc}))
 		{
